Learn R Programming

factset.protobuf.stachextensions (version 1.0.4)

V2ColumnOrganizedStachUtilities: V2ColumnOrganizedStachUtilities

Description

Provide helper functions for column organized stach

Arguments

Methods


Method GetPrimaryTableIds()

Get Primary Table Ids

Usage

V2ColumnOrganizedStachUtilities$GetPrimaryTableIds(package)

Arguments

package

Stach Data which is represented as a Package object

Returns

Returns list of primary table ids


Method Decompress()

Get decompress stach data

Usage

V2ColumnOrganizedStachUtilities$Decompress(package)

Arguments

package

Stach Data which is represented as a Package object

Returns

Returns decompressed stach data


Method clone()

The objects of this class are cloneable with this method.

Usage

V2ColumnOrganizedStachUtilities$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

Run this code
if (FALSE) {
compressedFilePath <- 'Path of your json file'
compressedData <- jsonlite::read_json(path=compressedFilePath,
auto_unbox=TRUE)
stachUtilities <-
factset.protobuf.stachextensions::V2ColumnOrganizedStachUtilities
primaryTableIds <-
stachUtilities$public_methods$GetPrimaryTableIds(compressedData)
}

if (FALSE) {
compressedFilePath <- 'Path of your json file'
compressedData <- jsonlite::read_json(path=compressedFilePath,
auto_unbox=TRUE)
utility <-
factset.protobuf.stachextensions::V2ColumnOrganizedStachUtilities$new()
deCompressedData <- utility$Decompress(compressedData)
}

Run the code above in your browser using DataLab