Learn R Programming

factset.protobuf.stachextensions (version 1.0.4)

V2StachUtilities: V2StachUtilities

Description

The purpose of this class is to provide the helper methods

Arguments

Methods


Method GetMappingObject()

Helper method for getting the value corresponding to the given key from the object.

Usage

V2StachUtilities$GetMappingObject(objectMap, key, keyname = "key")

Arguments

objectMap

Mapping object value

key

Mapping object corresponding key value

keyname

Mapping object corresponding key name

Returns

Returns the value corresponding to the given key from the object


Method ValueToString()

Helper method for converting value to string

Usage

V2StachUtilities$ValueToString(value)

Arguments

value

Value that should be converted to string

Returns

Returns the value by converting corresponding value to string


Method clone()

The objects of this class are cloneable with this method.

Usage

V2StachUtilities$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

Run this code
if (FALSE) {
package <- 'Stach data which is converted into RowOrganized Package'
tableData <-
V2StachUtilities$public_methods$GetMappingObject(package$tables,
primaryTableId)$value
}

Run the code above in your browser using DataLab