powered by
The purpose of this class is to provide the helper methods
V2StachUtilities$GetMappingObject()
V2StachUtilities$ValueToString()
V2StachUtilities$clone()
GetMappingObject()
Helper method for getting the value corresponding to the given key from the object.
V2StachUtilities$GetMappingObject(objectMap, key, keyname = "key")
objectMap
Mapping object value
key
Mapping object corresponding key value
keyname
Mapping object corresponding key name
Returns the value corresponding to the given key from the object
ValueToString()
Helper method for converting value to string
V2StachUtilities$ValueToString(value)
value
Value that should be converted to string
Returns the value by converting corresponding value to string
clone()
The objects of this class are cloneable with this method.
V2StachUtilities$clone(deep = FALSE)
deep
Whether to make a deep clone.
if (FALSE) { package <- 'Stach data which is converted into RowOrganized Package' tableData <- V2StachUtilities$public_methods$GetMappingObject(package$tables, primaryTableId)$value }
Run the code above in your browser using DataLab